EXPORTS
	?GetChecksum@CEdidParserBase@@QAEEXZ @ 1 NONAME ; unsigned char CEdidParserBase::GetChecksum(void)
	?CreateCea861ExtensionParserL@CEdidParserBase@@QAEPAVCCea861EdidParser@@H@Z @ 2 NONAME ; class CCea861EdidParser * CEdidParserBase::CreateCea861ExtensionParserL(int)
	?IsAudioDataBlockSupported@CCea861EdidParser@@QAEHXZ @ 3 NONAME ; int CCea861EdidParser::IsAudioDataBlockSupported(void)
	?GetManufacturerCode@CEdidParserBase@@QAEXAAVTDes16@@@Z @ 4 NONAME ; void CEdidParserBase::GetManufacturerCode(class TDes16 &)
	?YCbCr422@CCea861EdidParser@@QAEHXZ @ 5 NONAME ; int CCea861EdidParser::YCbCr422(void)
	?GetManufacturerTimings@CEdidParserBase@@QAEEXZ @ 6 NONAME ; unsigned char CEdidParserBase::GetManufacturerTimings(void)
	?IsAspectRatioUsed@CEdidParserBase@@QAEHXZ @ 7 NONAME ; int CEdidParserBase::IsAspectRatioUsed(void)
	?GetColorCoordinatesWhiteY@CEdidParserBase@@QAEGXZ @ 8 NONAME ; unsigned short CEdidParserBase::GetColorCoordinatesWhiteY(void)
	?GetColorCoordinatesRedX@CEdidParserBase@@QAEGXZ @ 9 NONAME ; unsigned short CEdidParserBase::GetColorCoordinatesRedX(void)
	?GetVIC@CCea861EdidParser@@QAECE@Z @ 10 NONAME ; signed char CCea861EdidParser::GetVIC(unsigned char)
	?IsVideoDataBlockSupported@CCea861EdidParser@@QAEHXZ @ 11 NONAME ; int CCea861EdidParser::IsVideoDataBlockSupported(void)
	?NewL@CCea861ExtEdidInformation@@SAPAV1@XZ @ 12 NONAME ; class CCea861ExtEdidInformation * CCea861ExtEdidInformation::NewL(void)
	?NewL@CCea861EdidParser@@SAPAV1@AAY0IA@E@Z @ 13 NONAME ; class CCea861EdidParser * CCea861EdidParser::NewL(unsigned char [128] &)
	?GetVersion@CEdidParserBase@@QAEEXZ @ 14 NONAME ; unsigned char CEdidParserBase::GetVersion(void)
	?GetExtensionType@CEdidParserBase@@QAE?AW4TEdidExtensionTagCode@@H@Z @ 15 NONAME ; enum TEdidExtensionTagCode CEdidParserBase::GetExtensionType(int)
	?Underscan@CCea861EdidParser@@QAEHXZ @ 16 NONAME ; int CCea861EdidParser::Underscan(void)
	?GetHorizontalScreenSize@CEdidParserBase@@QAEEXZ @ 17 NONAME ; unsigned char CEdidParserBase::GetHorizontalScreenSize(void)
	?BasicAudio@CCea861EdidParser@@QAEHXZ @ 18 NONAME ; int CCea861EdidParser::BasicAudio(void)
	?IsSpeakerAllocationDataBlockSupported@CCea861EdidParser@@QAEHXZ @ 19 NONAME ; int CCea861EdidParser::IsSpeakerAllocationDataBlockSupported(void)
	?GetVideoInputDefinition@CEdidParserBase@@QAEEXZ @ 20 NONAME ; unsigned char CEdidParserBase::GetVideoInputDefinition(void)
	?GetManufactureWeek@CEdidParserBase@@QAEEXZ @ 21 NONAME ; unsigned char CEdidParserBase::GetManufactureWeek(void)
	?GetColorCoordinatesGreenX@CEdidParserBase@@QAEGXZ @ 22 NONAME ; unsigned short CEdidParserBase::GetColorCoordinatesGreenX(void)
	?GetNumberOfExtensions@CEdidParserBase@@QAEEXZ @ 23 NONAME ; unsigned char CEdidParserBase::GetNumberOfExtensions(void)
	?GetEstablishedTimings1@CEdidParserBase@@QAEEXZ @ 24 NONAME ; unsigned char CEdidParserBase::GetEstablishedTimings1(void)
	?GetParsedInformation@CCea861EdidParser@@QAEPAVCCea861ExtEdidInformation@@XZ @ 25 NONAME ; class CCea861ExtEdidInformation * CCea861EdidParser::GetParsedInformation(void)
	?NewL@CEdidParserBase@@SAPAV1@ABVTDesC8@@@Z @ 26 NONAME ; class CEdidParserBase * CEdidParserBase::NewL(class TDesC8 const &)
	?GetManufactureYear@CEdidParserBase@@QAEGXZ @ 27 NONAME ; unsigned short CEdidParserBase::GetManufactureYear(void)
	?GetVerticalScreenSize@CEdidParserBase@@QAEEXZ @ 28 NONAME ; unsigned char CEdidParserBase::GetVerticalScreenSize(void)
	?GetVideoLatency@CCea861EdidParser@@QAEEXZ @ 29 NONAME ; unsigned char CCea861EdidParser::GetVideoLatency(void)
	?TotalNumberOfNativeFormats@CCea861EdidParser@@QAEEXZ @ 30 NONAME ; unsigned char CCea861EdidParser::TotalNumberOfNativeFormats(void)
	?ParseExtensionBlockL@CCea861EdidParser@@QAEHAAY0IA@E@Z @ 31 NONAME ; int CCea861EdidParser::ParseExtensionBlockL(unsigned char [128] &)
	?GetAspectRatioPortrait@CEdidParserBase@@QAEEXZ @ 32 NONAME ; unsigned char CEdidParserBase::GetAspectRatioPortrait(void)
	?GetColorCoordinatesBlueX@CEdidParserBase@@QAEGXZ @ 33 NONAME ; unsigned short CEdidParserBase::GetColorCoordinatesBlueX(void)
	?GetColorCoordinatesRedY@CEdidParserBase@@QAEGXZ @ 34 NONAME ; unsigned short CEdidParserBase::GetColorCoordinatesRedY(void)
	?IsVendorSpecificDataBlockSupported@CCea861EdidParser@@QAEHXZ @ 35 NONAME ; int CCea861EdidParser::IsVendorSpecificDataBlockSupported(void)
	?NewLC@CEdidParserBase@@SAPAV1@ABVTDesC8@@@Z @ 36 NONAME ; class CEdidParserBase * CEdidParserBase::NewLC(class TDesC8 const &)
	?GetAudioLatency@CCea861EdidParser@@QAEEXZ @ 37 NONAME ; unsigned char CCea861EdidParser::GetAudioLatency(void)
	?GetAspectRatioLandscape@CEdidParserBase@@QAEEXZ @ 38 NONAME ; unsigned char CEdidParserBase::GetAspectRatioLandscape(void)
	?GetColorCoordinatesGreenY@CEdidParserBase@@QAEGXZ @ 39 NONAME ; unsigned short CEdidParserBase::GetColorCoordinatesGreenY(void)
	?GetProductId@CEdidParserBase@@QAEXAAVTDes16@@@Z @ 40 NONAME ; void CEdidParserBase::GetProductId(class TDes16 &)
	?GetColorCoordinatesWhiteX@CEdidParserBase@@QAEGXZ @ 41 NONAME ; unsigned short CEdidParserBase::GetColorCoordinatesWhiteX(void)
	?GetEstablishedTimings2@CEdidParserBase@@QAEEXZ @ 42 NONAME ; unsigned char CEdidParserBase::GetEstablishedTimings2(void)
	?YCbCr444@CCea861EdidParser@@QAEHXZ @ 43 NONAME ; int CCea861EdidParser::YCbCr444(void)
	?GetDescriptorBlock@CEdidParserBase@@QBE?AUTEdidDescriptorBlock@@E@Z @ 44 NONAME ; struct TEdidDescriptorBlock CEdidParserBase::GetDescriptorBlock(unsigned char) const
	?DisplayTransferCharacteristics@CEdidParserBase@@QAEEXZ @ 45 NONAME ; unsigned char CEdidParserBase::DisplayTransferCharacteristics(void)
	?NewLC@CCea861ExtEdidInformation@@SAPAV1@XZ @ 46 NONAME ; class CCea861ExtEdidInformation * CCea861ExtEdidInformation::NewLC(void)
	?NewLC@CCea861EdidParser@@SAPAV1@AAY0IA@E@Z @ 47 NONAME ; class CCea861EdidParser * CCea861EdidParser::NewLC(unsigned char [128] &)
	?ReadExtension@CEdidParserBase@@QAEHH@Z @ 48 NONAME ; int CEdidParserBase::ReadExtension(int)
	?IsEdidData@CEdidParserBase@@QAEHABVTDesC8@@@Z @ 49 NONAME ; int CEdidParserBase::IsEdidData(class TDesC8 const &)
	?IsExtensionBlockParsed@CCea861EdidParser@@QAEHXZ @ 50 NONAME ; int CCea861EdidParser::IsExtensionBlockParsed(void)
	?GetColorCoordinatesBlueY@CEdidParserBase@@QAEGXZ @ 51 NONAME ; unsigned short CEdidParserBase::GetColorCoordinatesBlueY(void)
	?GetRevision@CEdidParserBase@@QAEEXZ @ 52 NONAME ; unsigned char CEdidParserBase::GetRevision(void)
	?GetInterlacedAudioLatency@CCea861EdidParser@@QAEEXZ @ 53 NONAME ; unsigned char CCea861EdidParser::GetInterlacedAudioLatency(void)
	?GetInterlacedVideoLatency@CCea861EdidParser@@QAEEXZ @ 54 NONAME ; unsigned char CCea861EdidParser::GetInterlacedVideoLatency(void)
	?GetStandardTimings@CEdidParserBase@@QAEEH@Z @ 55 NONAME ; unsigned char CEdidParserBase::GetStandardTimings(int)

